@@ -3,7 +3,7 @@
 export BIN_DIR=`dirname $0`
 export PROJECT_ROOT="${BIN_DIR}/.."
 . "${PROJECT_ROOT}/name.py"
-export VIRTUALENV=${VIRTUALENV:="${app_name}back"}
+export VIRTUALENV=${VIRTUALENV:="${app_name}"}
 export FLASK_ENV=${FLASK_ENV:="production"}
 export PY_VERSION=${PY_VERSION:="3.7"}
 export SYSPKG=${SYSPKG:="no"}
